==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_results/mp0056_001/MP0056_GetWorkOrderScheduleDefault_001_Result.java <==

package net.datastream.schemas.mp_results.mp0056_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_results/MP0056_001}WorkOrder"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0056_GetWorkOrderScheduleDefault_001_Result")
public class MP0056_GetWorkOrderScheduleDefault_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP0056_GetWorkOrderScheduleDefault_001_Result.ResultData resultData;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP0056_GetWorkOrderScheduleDefault_001_Result.ResultData }
     *     
     */
    public MP0056_GetWorkOrderScheduleDefault_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP0056_GetWorkOrderScheduleDefault_001_Result.ResultData }
     *     
     */
    public void setResultData(MP0056_GetWorkOrderScheduleDefault_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0056_001}WorkOrder"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "workOrder"
    })
    public static class ResultData {

        @XmlElement(name = "WorkOrder", required = true)
        protected WorkOrder workOrder;

        /**
         * Obtient la valeur de la propriété workOrder.
         * 
         * @return
         *     possible object is
         *     {@link WorkOrder }
         *     
         */
        public WorkOrder getWorkOrder() {
            return workOrder;
        }

        /**
         * Définit la valeur de la propriété workOrder.
         * 
         * @param value
         *     allowed object is
         *     {@link WorkOrder }
         *     
         */
        public void setWorkOrder(WorkOrder value) {
            this.workOrder = value;
        }

    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_results/mp0056_001/MP0056_GetWorkOrderScheduleDefault_001_Result.java <==

package net.datastream.schemas.mp_results.mp0056_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_results/MP0056_001}WorkOrder"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0056_GetWorkOrderScheduleDefault_001_Result")
public class MP0056_GetWorkOrderScheduleDefault_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP0056_GetWorkOrderScheduleDefault_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP0056_GetWorkOrderScheduleDefault_001_Result.ResultData }
     *     
     */
    public MP0056_GetWorkOrderScheduleDefault_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP0056_GetWorkOrderScheduleDefault_001_Result.ResultData }
     *     
     */
    public void setResultData(MP0056_GetWorkOrderScheduleDefault_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0056_001}WorkOrder"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "workOrder"
    })
    public static class ResultData {

        @XmlElement(name = "WorkOrder", required = true)
        protected WorkOrder workOrder;

        /**
         * Gets the value of the workOrder property.
         * 
         * @return
         *     possible object is
         *     {@link WorkOrder }
         *     
         */
        public WorkOrder getWorkOrder() {
            return workOrder;
        }

        /**
         * Sets the value of the workOrder property.
         * 
         * @param value
         *     allowed object is
         *     {@link WorkOrder }
         *     
         */
        public void setWorkOrder(WorkOrder value) {
            this.workOrder = value;
        }

    }

}
